act.plotting.act\_cmap
======================

.. automodule:: act.plotting.act_cmap

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      revcmap
   
   

   
   
   

   
   
   



